@@ -2,13 +2,14 @@
 
 import logging as _logging
 
-from ._core import Repository
+from ._repo import BasicRepo, Repo, TaggedRepo
+from ._uow import UnitOfWork
 
 
-__all__ = ["Repository"]
+__all__ = ["BasicRepo", "Repo", "TaggedRepo", "UnitOfWork"]
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.2.0"
+__version__ = "0.3.1"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
